import React from "react";
import PropTypes from "prop-types";
import {Button, ButtonToolbar, Panel} from "react-bootstrap";

import I18nWrapper from "../../i18n/I18nWrapper";
import injectIntl from "../../utils/injectIntl";
import Input from "../Input";
import Occurrence from "./occurrence/Occurrence";
import ReportProvenance from "./ReportProvenance";
import ReportValidator from "../../validator/ReportValidator";

class Report extends React.Component {
    constructor(props) {
        super(props);
        this.i18n = props.i18n;
    }

    _onChange = (e) => {
        const change = {};
        change[e.target.name] = e.target.value;
        this.props.onChange(change);
    };

    render() {
        const report = this.props.report,
            valid = ReportValidator.isValid(report);
        if (!report) {
            return <Panel header={<h2 className='panel-title pull-left'>{this.i18n('occurrencereport.title')}</h2>}
                          bsStyle='primary'/>;
        }
        return <Panel header={<h3>{this.i18n('occurrencereport.title')}</h3>}
                      bsStyle='primary'>
            <Occurrence occurrence={report.occurrence} onChange={this.props.onChange}/>

            <div className='row'>
                <div className='col-xs-12'>
                    <Input type='textarea' name='narrative' label={this.i18n('narrative')} rows={8}
                           placeholder={this.i18n('narrative')} title={this.i18n('report.narrative-tooltip')}
                           value={report.narrative} onChange={this._onChange}/>
                </div>
            </div>

            <div className='row'>
                <div className='col-xs-12'>
                    <ReportProvenance report={report}/>
                </div>
            </div>

            <ButtonToolbar className='float-right detail-button-toolbar'>
                <Button bsStyle='success' bsSize='small'
                        title={this.i18n(valid ? 'detail.save-tooltip' : 'detail.invalid-tooltip')}
                        onClick={this.props.save} disabled={!valid}>
                    {this.i18n('save')}
                </Button>
                <Button bsStyle='link' bsSize='small' title={this.i18n('cancel-tooltip')}
                        onClick={this.props.cancel}>{this.i18n('cancel')}</Button>
            </ButtonToolbar>
        </Panel>;
    }
}

Report.propTypes = {
    report: PropTypes.object,
    onChange: PropTypes.func.isRequired,
    save: PropTypes.func.isRequired,
    cancel: PropTypes.func.isRequired
};

export default injectIntl(I18nWrapper(Report));
